# Plots

## compute_diagnostics

```{eval-rst}
.. autofunction:: openpkpd.plots.diagnostics.compute_diagnostics
```

## GOF plots

```{eval-rst}
.. autofunction:: openpkpd.plots.gof.diagnostic_panel
.. autofunction:: openpkpd.plots.gof.dv_vs_ipred
.. autofunction:: openpkpd.plots.gof.dv_vs_pred
.. autofunction:: openpkpd.plots.gof.cwres_vs_time
.. autofunction:: openpkpd.plots.gof.cwres_vs_pred
.. autofunction:: openpkpd.plots.gof.cwres_qq
.. autofunction:: openpkpd.plots.gof.abs_iwres_vs_ipred
```

## PK plots

```{eval-rst}
.. autofunction:: openpkpd.plots.pk.spaghetti_plot
.. autofunction:: openpkpd.plots.pk.concentration_time
.. autofunction:: openpkpd.plots.pk.mean_profile
```

## PD plots

```{eval-rst}
.. autofunction:: openpkpd.plots.pd.effect_time
.. autofunction:: openpkpd.plots.pd.emax_curve
.. autofunction:: openpkpd.plots.pd.hysteresis_loop
.. autofunction:: openpkpd.plots.pd.pd_individual
```

## ETA plots

```{eval-rst}
.. autofunction:: openpkpd.plots.eta.eta_histograms
.. autofunction:: openpkpd.plots.eta.eta_pairs
.. autofunction:: openpkpd.plots.eta.eta_vs_covariate
```

## Model performance

```{eval-rst}
.. autofunction:: openpkpd.plots.model_perf.ofv_history
.. autofunction:: openpkpd.plots.model_perf.vpc
```
